@@ -340,6 +340,7 @@ class PolarsExpr:
     arg_max: Method[Self]
     arg_min: Method[Self]
     arg_true: Method[Self]
+    ceil: Method[Self]
     clip: Method[Self]
     count: Method[Self]
     cum_max: Method[Self]
@@ -352,6 +353,7 @@ class PolarsExpr:
     fill_null: Method[Self]
     fill_nan: Method[Self]
     first: Method[Self]
+    floor: Method[Self]
     last: Method[Self]
     gather_every: Method[Self]
     head: Method[Self]
